@@ -2,9 +2,9 @@
 ### ====================================================================
 ###  @UNIX-shell-file{
 ###     author          = "Nelson H. F. Beebe",
-###     version         = "0.09",
-###     date            = "17 January 1996",
-###     time            = "07:54:42 MST",
+###     version         = "0.10",
+###     date            = "16 September 1996",
+###     time            = "19:07:43 MDT",
 ###     filename        = "bibsort.sh",
 ###     address         = "Center for Scientific Computing
 ###                        Department of Mathematics
@@ -13,7 +13,7 @@
 ###                        USA",
 ###     telephone       = "+1 801 581 5254",
 ###     FAX             = "+1 801 581 4148",
-###     checksum        = "22155 646 2840 24287",
+###     checksum        = "35134 653 2875 24557",
 ###     email           = "beebe@math.utah.edu (Internet)",
 ###     codetable       = "ISO/ASCII",
 ###     keywords        = "bibliography, sorting, BibTeX",
@@ -56,7 +56,7 @@
 ###
 ###                        With -byday sorting, a day keyword is
 ###                        recognized (it will be standard in BibTeX
-###                        1.0), but for backward compability, month
+###                        1.0), but for backward compatibility, month
 ###                        entries of the form
 ###
 ###                        <quote>daynumber <quote> # monthname
@@ -493,23 +493,30 @@ function print_braced_item(count)
     }
 }
 
-function print_item(prefix,citation_key,item, extra_key,v)
+function print_item(prefix,citation_key,item, extra_key,second_extra_key,v)
 {
     if (citation_key in cross_referenced_item) # change prefix if this item
 	prefix = prefix_cross_referenced # was cross-referenced earlier
 
+    second_extra_key = ""
     if (BYDAY)
 	extra_key = day_key(item,citation_key)
     else if (BYVOLUME)
 	extra_key = volume_key(item,citation_key)
     else if (BYYEAR)
+    {
 	extra_key = (match(item,/:[12][0-9][0-9x][0-9x]:/)) ? \
 	    substr(item,RSTART,RLENGTH) : \
 	    (":" value(item,citation_key,"year[ \t]*=[ \t]*") ":")
+	# Now add a volume key too, so that identical labels
+	# in a periodical bibliography (e.g. from a regular column)
+	# sort in publication order
+	second_extra_key = volume_key(item,citation_key)
+    }
     else
 	extra_key = ""
 
-    print sort_key prefix extra_key citation_key hidden_newline
+    print sort_key prefix extra_key citation_key second_extra_key hidden_newline
     printf("%s", item)
 
     # Check for use of crossref = "citation-key": such items must be
